.. katsdpimager documentation master file, created by
   sphinx-quickstart on Fri May  8 09:38:35 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to katsdpimager's documentation!
========================================

Contents:

.. toctree::
   :maxdepth: 2

   user.rst
   changelog.rst
   modules.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

